#
# Conditional build:
%bcond_without	doc	# Sphinx documentation
%bcond_without	tests	# unit tests
%bcond_without	python2 # CPython 2.x module
%bcond_without	python3 # CPython 3.x module

%define		module		ZConfig
Summary:	Structured Configuration Library
Summary(pl.UTF-8):	Biblioteka ustrukturyzowanych plików konfiguracyjnych
Name:		python3-%{module}
Version:	4.2
Release:	1
License:	ZPL v2.1
Group:		Libraries/Python
Source0:	https://files.pythonhosted.org/packages/source/Z/ZConfig/zconfig-%{version}.tar.gz
# Source0-md5:	93441a72f1598d0f39bf93fe6320f628
URL:		https://github.com/zopefoundation/ZConfig/
BuildRequires:	python3-modules >= 1:3.9
BuildRequires:	python3-setuptools
%if %{with tests}
BuildRequires:	python3-docutils
BuildRequires:	python3-manuel
BuildRequires:	python3-zope.exceptions
BuildRequires:	python3-zope.testrunner
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with doc}
BuildRequires:	python3-sphinx_rtd_theme
BuildRequires:	python3-sphinxcontrib-programoutput
BuildRequires:	sphinx-pdg-3
%endif
Requires:	python3-modules >= 1:3.9
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
ZConfig is a configuration library intended for general use. It
supports a hierarchical schema-driven configuration model that allows
a schema to specify data conversion routines written in Python.
ZConfig's model is very different from the model supported by the
ConfigParser module found in Python's standard library, and is more
suitable to configuration-intensive applications.

%description -l pl.UTF-8
ZConfig to biblioteka konfiguracji, przeznaczona do ogólnego użytku.
Obsługuje hierarchiczny, oparty na schematach model konfiguracji,
pozwalający na określanie w schematach napisanych w Pythonie procedur
konwersji danych. Model ZConfig różni się znacząco od modelu
obsługiwanego przez moduł ConfigParser z biblioteki standardowej
Pythona i bardziej odpowiada aplikacjon korzystającym intensywnie z
konfiguracji.

%package apidocs
Summary:	API documentation for Python %{module} module
Summary(pl.UTF-8):	Dokumentacja API modułu Pythona %{module}
Group:		Documentation

%description apidocs
API documentation for Pythona %{module} module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu Pythona %{module}.

%prep
%setup -q -n zconfig-%{version}

mkdir -p stubs
cat >stubs/zconfig <<EOF
#!/bin/sh
%{__python} $(pwd)/src/ZConfig/validator.py "\$@"
EOF
cat >stubs/zconfig_schema2html <<EOF
#!/bin/sh
%{__python} $(pwd)/src/ZConfig/schema2html.py "\$@" 
EOF
chmod 755 stubs/zconfig*

%build
%py3_build

%if %{with tests}
PYTHONPATH=$(pwd)/src \
zope-testrunner-3 --test-path=src -v
%endif

%if %{with doc}
PATH=$(pwd)/stubs:$PATH \
PYTHONPATH=$(pwd)/src \
%{__make} -C docs html \
	SPHINXBUILD=sphinx-build-3
%endif

%install
rm -rf $RPM_BUILD_ROOT

%py3_install

%{__rm} -r $RPM_BUILD_ROOT%{py3_sitescriptdir}/ZConfig/tests

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc CHANGES.rst COPYRIGHT.txt LICENSE.txt README.rst
%attr(755,root,root) %{_bindir}/zconfig
%attr(755,root,root) %{_bindir}/zconfig_schema2html
%{py3_sitescriptdir}/ZConfig
%{py3_sitescriptdir}/ZConfig-%{version}-py*.egg-info

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/_build/html/{_static,*.html,*.js}
%endif
%changelog
* Fri May 09 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python3-ZConfig.git;a=log;h=master

* Fri May 09 2025 Jakub Bogusz <qboosh@pld-linux.org> 958b329
- python-ZConfig.spec updated to 4.2 for python 3.9+

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> e215d85
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> 636181f
- python 3.13 rebuild

* Mon Jan 08 2024 Jakub Bogusz <qboosh@pld-linux.org> a9bc4fc
- updated to 3.6.1

* Mon Jan 08 2024 Jakub Bogusz <qboosh@pld-linux.org> fbd57c5
- cleanup, pl

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> a5d8922
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> 63f60d7
- Release 7 (by relup.sh)

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> a3b4d34
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 70f918f
- rebuild with python 3.10

* Fri Feb 26 2021 Jan Rękorajski <baggins@pld-linux.org> bc038eb
- release 4 (by relup.sh)

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> a96dd33
- rebuild with python 3.8
- release 3 (by relup.sh)

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 5b67add
- python 3.7 rebuild
- release 2 (by relup.sh)

* Sun Nov 12 2017 Mateusz Korniak <matkor@pld-linux.org> cd408d9
- Initial 3.2.0. Rel 1.

